Examples
========

See the **Example** section for each of these functions:

:func:`cappr.openai.classify.predict`

:func:`cappr.huggingface.classify.predict`

:func:`cappr.llama_cpp.classify.predict`

:func:`cappr.openai.classify.predict_examples`

:func:`cappr.huggingface.classify.predict_examples`

:func:`cappr.llama_cpp.classify.predict_examples`

And see the `Usage`_ section in the README, and the `demos in the repo`_.

.. _Usage: https://github.com/kddubey/cappr/tree/main#usage

.. _demos in the repo: https://github.com/kddubey/cappr/tree/main/demos
